@@ -7,7 +7,7 @@ use Mojo::Base 'Mojolicious::Plugin::Prove::Base';
 use File::Basename;
 use File::Spec;
 
-our $VERSION = '0.05';
+our $VERSION = '0.06';
 
 sub register {
     my ($self, $app, $conf) = @_;
@@ -48,8 +48,9 @@ sub register {
         );
         
         $r->get('/')->to( '#list' );
-        $r->get('/test/*name/*file/run')->to( '#run' );
-        $r->get('/test/*name/*file')->to( '#file' );
+        $r->get('/test/*name/file/*file/run')->to( '#run' );
+        $r->get('/test/*name/file/*file')->to( '#file' );
+        $r->get('/test/*name/run')->to( '#run' );
         $r->get('/test/*name')->to( '#list' );
     }
 }
@@ -68,7 +69,7 @@ Mojolicious::Plugin::Prove - run test scripts via browser
 
 =head1 VERSION
 
-version 0.05
+version 0.06
 
 =head1 SYNOPSIS
 
